pytilities.tests — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.tests

`pytilities.tests.` `is_iterable`(obj)

  Test if something is iterable

  Parameters: | obj – any object

`pytilities.tests.` `is_private`(name)

  Test if name corresponds to a private attribute

  Private attribute names are of format __name or _SomeClass_name

  Parameters: | name (string) – Attribute name to test

`pytilities.tests.` `is_protected`(name)

  Test if name corresponds to a protected attribute

  Protected attribute names start ‘_’, but don’t contain ‘__’.

  Parameters: | name (string) – Attribute name to test

`pytilities.tests.` `is_public`(name)

  Test if name corresponds to a public attribute

  Names that do not start with ‘_’ are public.

  Parameters: | name (string) – Attribute name to test

`pytilities.tests.` `is_special`(name)

  Test if name corresponds to a special attribute

  Special attribute names start and end with ‘__’.

  Parameters: | name (string) – Attribute name to test

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »